#!/bin/sh

cd $(dirname "$0")

LOCALE_PATH=/boot/home/config/share/ftpfs/locale
SETTINGS=/boot/home/config/boot/UserSetupEnvironment

function printWelcomeMessage {
	echo FTP-FS Language Configuration
	echo
	echo Choose from one of the following languages:
	echo
}

function printPrompt {
	echo
	echo -n $'Enter the language code? ' 
}

function printCatalogValue {
	file="$1"
	field="$2"
	cat "$file" | ( while read line ; do
			if [ "$line" == "$field" ] ; then
				read value
				echo -n "$value "
				break
			fi
		done
	)	
}

function printLanguageCode {
	printCatalogValue "$1" LanguageCode
	printCatalogValue "$1" CatalogName
}

function printLanguages {
	( cd "$LOCALE_PATH"
	for file in *.catalog ; do
		if [ "$file" != "Template.catalog" ] ; then
			printLanguageCode "$file"
			echo
		fi
	done
	)
}

function queryTestLanguage {
	code="$1"
	message=$'Do you want to test the selected language?

Note: After clicking on Test the FTP-FS mount window will be opened. Please close this window to continue with the language configuration.'
	result=$(alert --info "$message" "Test" "Ignore")

	if [ "$result" == "Test" ] ; then
		return 0
	fi

	return 1
}

function testLanguage {
	code="$1"
	export LC_MESSAGES="$code"
	FTP-FS\ Mount bookmarks/FTP\ Bookmark
}

function queryStoreLanguage {
	code="$1"
	message=$'Do you want to store the language code in file UserSetupEnvironment?

Note: If the language code is not stored, FTP-FS will use English as the default language after the next restart of BeOS.'
	result=$(alert --info "$message" "Store settings" "Do not store settings" )

	if [ "$result" == "Store settings" ] ; then
		return 0
	fi

	return 1
}

function storeLanguage {
	code="$1"
	EXPORT=$'export LC_MESSAGES='$code
	if grep -q "export LC_MESSAGES" "$SETTINGS" ; then
		# replace
		mv $SETTINGS $SETTINGS.old
		sed -e "s/export LC_MESSAGES=.*/$EXPORT/" $SETTINGS.old > $SETTINGS
		rm $SETTINGS.old
	else
		# append
		echo "$EXPORT" >> $SETTINGS
	fi
}

function queryQuit {
	code="$1"
	message=$'Do you want to quit the FTP-FS language configuration?'
	result=$(alert --info "$message" "Try again" "Bye")

	if [ "$result" == "Bye" ] ; then
		return 0
	fi

	return 1
}


function restartTracker {
	export LC_MESSAGES=$1
	quit application/x-vnd.Be-TRAK  
	message=$'When Tracker has been terminated completely, click on Launch Tracker now.'
	void=$(alert --info "$message" "Launch Tracker now")
	/system/Tracker 2> /dev/null > /dev/null &
}

function queryRestartTracker {
	message=$'Tracker has to be restarted for FTP-FS to use the new settings.'
	result=$(alert --info "$message" "Restart Tracker" "$1" )

	if [ "$result" == "Restart Tracker" ] ; then
		return 0
	fi

	return 1
}

function selectLanguage {
	printWelcomeMessage
	printLanguages
	printPrompt
	read code

	if [ "$code" != "quit" ] ; then
		if queryTestLanguage $code ; then
			testLanguage $code
		fi
		if queryStoreLanguage $code ; then
			storeLanguage $code
			if queryRestartTracker Quit ; then
				restartTracker
			fi
			exit
		fi
		if queryRestartTracker Continue ; then
			restartTracker
		fi
		if queryQuit ; then
			exit
		fi
	else
		exit
	fi
}

function detectZeta {
	test "$(uname -n)" = "Zeta"
}

function isLanguageSet {
	test -n "$LC_MESSAGES"
}

function queryZetaSetAnyway {
	message=$'The operating system Zeta has been detected.\n\nDo you want to change the language anyway?'
	skip='Skip'
	change='Change Language'
	result=$(alert --info "$message" "$change" "$skip")
	if [ "$result" = "$change" ] ; then
		return 0
	else
		return 1
	fi
	test "$result" = "$change"
}

function skipZetaLanguageSelection {
	isLanguageSet
	if [ ! $? ] ; then
		return 1
	fi

	
	if queryZetaSetAnyway ; then
		return 1
	fi

	return 0
}

function main {
	if [ "$1" == "terminal" ] ; then
		while true ; do
			selectLanguage
		done
	else
		if detectZeta ; then
			if skipZetaLanguageSelection ; then
				exit
			fi
		fi
		# Launch script in a Terminal window
		Terminal -title "FTP-FS Language Configuration" "$0" terminal
	fi 
}

main $*